Kansas Supreme Court - Opinions Released

Kansas Opinions | Finding Aids: Case Name » Supreme Court or Court of Appeals | Docket Number | Release Date |

Kansas Supreme Court
Opinions Released October 3. 2014

Published Opinions

Published Opinions are available for viewing with Adobe Acrobat® Reader™.
Cite published opinions using the official citations followed by any generally recognized reporter citation System. SCR 6.08

Docket Number / Case Name
106210 - State v. Ortega video
108526 - Craig v. FedEx Ground Package System, Inc. video

Unpublished Opinions
Fulltext NOT available on the web.
Contact the Kansas Supreme Court Law Library at 785-296-3257 to obtain fulltext.

Docket Number / Case Name / Judge / Disposition / County
The Kansas Supreme Court did not release any unpublished opinions on October 3, 2014

NOTE: Slip opinions are subject to modification orders and editorial corrections prior to publication in the official reporters. Consult the bound volumes of Kansas Reports and Kansas Supreme Court Reports for the final, official texts of the opinions of the Kansas Supreme Court and the Kansas Supreme Court. Attorneys are requested to call prompt attention to typographical or other formal errors; please notify Richard Ross, Reporter of Decisions, Kansas Judicial Center, 301 West 10th, Topeka, KS 66612-1598; e-mail, rossr@kscourts.org; phone, 785-296-3214.

Kansas Opinions | Finding Aids: Case Name » Supreme Court or Court of Appeals | Docket Number | Release Date |